pub struct PackageProperties {
pub hash: Hash,
}Expand description
PackageProperties contains additional properties besides the package URL that apply to a package and can be provided. It is intended to be extensible.
Fields
hash: HashTrait Implementations
Sourceimpl Clone for PackageProperties
impl Clone for PackageProperties
Sourcefn clone(&self) -> PackageProperties
fn clone(&self) -> PackageProperties
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PackageProperties
impl Debug for PackageProperties
Sourceimpl<'de> Deserialize<'de> for PackageProperties
impl<'de> Deserialize<'de> for PackageProperties
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PackageProperties
Sourceimpl Hash for PackageProperties
impl Hash for PackageProperties
Sourceimpl PartialEq for PackageProperties
impl PartialEq for PackageProperties
Sourcefn eq(&self, other: &PackageProperties) -> bool
fn eq(&self, other: &PackageProperties) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PackageProperties
impl Serialize for PackageProperties
impl StructuralPartialEq for PackageProperties