pub struct BlobInfo {
pub source_path: String,
pub path: String,
pub merkle: Hash,
pub size: u64,
}Fields
source_path: StringPath to the blob file, could be a delivery blob or uncompressed blob depending on
delivery_blob_type in the manifest.
path: StringThe virtual path of the blob in the package.
merkle: Hashsize: u64Uncompressed size of the blob.