PackageManifest

Struct PackageManifest 

pub struct PackageManifest(/* private fields */);

Implementations

Source

impl PackageManifest

pub const META_FAR_BLOB_PATH: &'static str = "meta/"

Blob path used in package manifests to indicate the meta.far.

pub fn blobs(&self) -> &[BlobInfo]

Return a reference vector of blobs in this PackageManifest.

NB: Does not include blobs referenced by possible subpackages.

pub fn subpackages(&self) -> &[SubpackageInfo]

Returns a reference vector of SubpackageInfo in this PackageManifest.

pub fn into_blobs(self) -> Vec<BlobInfo>

Returns a vector of the blobs in the current PackageManifest.

pub fn into_blobs_and_subpackages(self) -> (Vec<BlobInfo>, Vec<SubpackageInfo>)

Returns a tuple of the current PackageManifest’s blobs and subpackages. blobs does not include blobs referenced by the subpackages.

pub fn name(&self) -> &PackageName

Returns the name from the PackageMetadata.

pub fn set_name(&mut self, name: PackageName)

Sets the name of the package.

pub async fn archive( self, root_dir: impl AsRef<Path>, out: impl Write, ) -> Result<(), PackageManifestError>

Write a package archive into the out file. The source files are relative to the root_dir directory.

pub fn package_path(&self) -> PackagePath

Returns a PackagePath formatted from the metadata of the PackageManifest.

pub fn repository(&self) -> Option<&str>

pub fn set_repository(&mut self, repository: Option<String>)

pub fn package_url(&self) -> Result<Option<UnpinnedAbsolutePackageUrl>>

pub fn hash(&self) -> Hash

Returns the merkle root of the meta.far.

Panics

Panics if the PackageManifest is missing a “meta/” entry

pub fn abi_revision(&self) -> Option<AbiRevision>

pub fn delivery_blob_type(&self) -> Option<DeliveryBlobType>

pub fn from_blobs_dir( blobs_dir_root: &Path, delivery_blob_type: Option<DeliveryBlobType>, meta_far_hash: Hash, out_manifest_dir: &Path, ) -> Result<Self, PackageManifestError>

Create a PackageManifest and populate a manifest directory given a blobs directory and the top level meta.far hash.

The blobs_dir_root directory must contain all the package blobs either uncompressed in root, or delivery blobs in a sub directory.

The out_manifest_dir will be a flat file populated with JSON representations of PackageManifests corresponding to the subpackages.

pub fn from_archive( archive_path: &Path, blobs_dir: &Path, out_manifest_dir: &Path, ) -> Result<Self, PackageManifestError>

Extract the package blobs from archive_path into the blobs_dir directory and extracts all the JSON representations of the subpackages’ PackageManifests and top level PackageManifest into out_manifest_dir.

Returns an in-memory PackageManifest for these files.

pub fn try_load_from(manifest_path: impl AsRef<Utf8Path>) -> Result<Self>

pub fn from_reader( manifest_path: impl AsRef<Utf8Path>, reader: impl Read, ) -> Result<Self>

pub fn package_and_subpackage_blobs( self, ) -> Result<(BlobInfo, HashMap<Hash, BlobInfo>), PackageManifestError>

Returns a tuple of a BlobInfo corresponding to the top level meta.far blob and a HashMap containing all of the blobs (both content blobs and meta.fars) from the transitive closure of the subpackages. The HashMap will not contain the BlobInfo of the top level meta.far.

pub fn write_with_relative_paths( self, path: impl AsRef<Utf8Path>, ) -> Result<Self>

pub fn write(&self, path: impl AsRef<Utf8Path>) -> Result<()>